==> massxpert2_8.4.1.orig.tar.gz: massxpert2-8.4.1/src/gui/RegionSelection.hpp <==
/* BEGIN software license
 *
 * msXpertSuite - mass spectrometry software suite
 * -----------------------------------------------
 * Copyright(C) 2009,...,2018 Filippo Rusconi
 *
 * http://www.msxpertsuite.org
 *
 * This file is part of the msXpertSuite project.
 *
 * The msXpertSuite project is the successor of the massXpert project. This
 * project now includes various independent modules:
 *
 * - massXpert, model polymer chemistries and simulate mass spectrometric data;
 * - mineXpert, a powerful TIC chromatogram/mass spectrum viewer/miner;
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 *
 * END software license
 */


#ifndef REGION_SELECTION_HPP
#define REGION_SELECTION_HPP


/////////////////////// Qt includes
#include <QList>
#include <QRect>
#include <QGraphicsRectItem>
#include <QPointF>


/////////////////////// Local includes
#include "libmass/Monomer.hpp"


namespace msxps
{

	namespace massxpert
	{



class SequenceEditorGraphicsView;
class Coordinates;
class Monomer;

class RegionSelection
{
  private:
  SequenceEditorGraphicsView *mp_view;

  QList<QRectF *> m_rectangleList;
  QList<QGraphicsRectItem *> m_markList;

  const libmass::Monomer *mp_startMonomer;
  const libmass::Monomer *mp_endMonomer;

  QPointF m_startPoint;
  QPointF m_endPoint;

  int m_startIndex;
  int m_endIndex;

  void setCoordinates(int, int);
  void setCoordinates(const QPointF &, const QPointF &);
  int drawMark();
  int eraseMark();

  public:
  RegionSelection(SequenceEditorGraphicsView *);

  ~RegionSelection(void);

  SequenceEditorGraphicsView *view();

  const libmass::Monomer *startMonomer() const;
  const libmass::Monomer *endMonomer() const;

  int startIndex() const;
  int endIndex() const;

  int redrawMark();
  int drawMark(int, int);
  int drawMark(const QPointF &, const QPointF &);

  bool encompassing(int = -1, int = -1);

  libmass::Coordinates *coordinates();

  void debugSelectionIndicesPutStdErr();
};

} // namespace massxpert

} // namespace msxps

#endif // REGION_SELECTION_HPP

==> massxpert_6.0.1.orig.tar.gz: massxpert-6.0.1/src/gui/RegionSelection.hpp <==
/* BEGIN software license
 *
 * msXpertSuite - mass spectrometry software suite
 * -----------------------------------------------
 * Copyright(C) 2009,...,2018 Filippo Rusconi
 *
 * http://www.msxpertsuite.org
 *
 * This file is part of the msXpertSuite project.
 *
 * The msXpertSuite project is the successor of the massXpert project. This
 * project now includes various independent modules:
 *
 * - massXpert, model polymer chemistries and simulate mass spectrometric data;
 * - mineXpert, a powerful TIC chromatogram/mass spectrum viewer/miner;
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 *
 * END software license
 */


#ifndef REGION_SELECTION_HPP
#define REGION_SELECTION_HPP


/////////////////////// Qt includes
#include <QList>
#include <QRect>
#include <QGraphicsRectItem>
#include <QPointF>


/////////////////////// Local includes


namespace msxps
{

	namespace massxpert
	{



class SequenceEditorGraphicsView;
class Coordinates;
class Monomer;

class RegionSelection
{
  private:
  SequenceEditorGraphicsView *mp_view;

  QList<QRectF *> m_rectangleList;
  QList<QGraphicsRectItem *> m_markList;

  const Monomer *mp_startMonomer;
  const Monomer *mp_endMonomer;

  QPointF m_startPoint;
  QPointF m_endPoint;

  int m_startIndex;
  int m_endIndex;

  void setCoordinates(int, int);
  void setCoordinates(const QPointF &, const QPointF &);
  int drawMark();
  int eraseMark();

  public:
  RegionSelection(SequenceEditorGraphicsView *);

  ~RegionSelection(void);

  SequenceEditorGraphicsView *view();

  const Monomer *startMonomer() const;
  const Monomer *endMonomer() const;

  int startIndex() const;
  int endIndex() const;

  int redrawMark();
  int drawMark(int, int);
  int drawMark(const QPointF &, const QPointF &);

  bool encompassing(int = -1, int = -1);

  Coordinates *coordinates();

  void debugSelectionIndicesPutStdErr();
};

} // namespace massxpert

} // namespace msxps

#endif // REGION_SELECTION_HPP
